import { useMemo, useCallback } from 'react';
import Picker from '../picker';
import { useControllableValue } from 'ahooks';
import dayjs from 'dayjs';
import { generateIntArray } from '../../utils/generate-int-array';
import { withDefaultProps } from '../../utils/with-default-props';
var thisYear = new Date().getFullYear();
var defaultProps = {
  min: new Date(new Date().setFullYear(thisYear - 10)),
  max: new Date(new Date().setFullYear(thisYear + 10))
};
var DatePicker = withDefaultProps(defaultProps)(function (props) {
  var _useControllableValue = useControllableValue(props, {
    trigger: 'onConfirm'
  }),
      value = _useControllableValue[0],
      setValue = _useControllableValue[1];

  function columns(selected) {
    var years = [];
    var minYear = props.min.getFullYear();
    var minMonth = props.min.getMonth() + 1;
    var minDate = props.min.getDate();
    var maxYear = props.max.getFullYear();
    var maxMonth = props.max.getMonth() + 1;
    var maxDate = props.max.getDate();
    var firstDayInSelectedMonth = dayjs(convertStringArrayToDate([selected[0], selected[1], '1']));
    var selectedYear = firstDayInSelectedMonth.year();
    var selectedMonth = firstDayInSelectedMonth.month() + 1;

    for (var i = minYear; i <= maxYear; i++) {
      years.push(i.toString());
    }

    var months = generateIntArray(1, 12).filter(function (v) {
      if (selectedYear === minYear && v < minMonth) {
        return false;
      }

      if (selectedYear === maxYear && v > maxMonth) {
        return false;
      }

      return true;
    }).map(function (v) {
      return v.toString();
    });
    var days = [];
    days = generateIntArray(1, firstDayInSelectedMonth.daysInMonth()).filter(function (v) {
      if (selectedYear === minYear && selectedMonth === minMonth && v < minDate) {
        return false;
      }

      if (selectedYear === maxYear && selectedMonth === maxMonth && v > maxDate) {
        return false;
      }

      return true;
    }).map(function (v) {
      return v.toString();
    });
    return [years, months, days];
  }

  var pickerValue = useMemo(function () {
    return convertDateToStringArray(value);
  }, [value]);
  var onConfirm = useCallback(function (val) {
    setValue(convertStringArrayToDate(val));
  }, [setValue]);
  var onSelect = useCallback(function (val) {
    props.onSelect == null ? void 0 : props.onSelect(convertStringArrayToDate(val));
  }, [props.onSelect]);
  return /*#__PURE__*/React.createElement(Picker, {
    columns: columns,
    value: pickerValue,
    onCancel: props.onCancel,
    onClose: props.onClose,
    visible: props.visible,
    confirmText: props.confirmText,
    cancelText: props.cancelText,
    onConfirm: onConfirm,
    onSelect: onSelect,
    getContainer: props.getContainer
  });
});

function convertDateToStringArray(date) {
  if (!date) return [];
  return [date.getFullYear().toString(), (date.getMonth() + 1).toString(), date.getDate().toString()];
}

function convertStringArrayToDate(value) {
  var _value$ = value[0],
      yearString = _value$ === void 0 ? '1900' : _value$,
      _value$2 = value[1],
      monthString = _value$2 === void 0 ? '1' : _value$2,
      _value$3 = value[2],
      dateString = _value$3 === void 0 ? '1' : _value$3;
  return new Date(parseInt(yearString), parseInt(monthString) - 1, parseInt(dateString));
}

export default DatePicker;