import React from 'react';
import classNames from 'classnames';
import { CheckCircleFilled, CloseCircleFilled } from '@ant-design/icons';
import Step from './step';
import { withDefaultProps } from '../../utils/with-default-props';
import { attachPropertiesToComponent } from '../../utils/attach-properties-to-component';
var classPrefix = "am-steps";
var stepClassPrefix = "am-step";
var defaultIconMap = {
  error: /*#__PURE__*/React.createElement(CloseCircleFilled, null),
  finish: /*#__PURE__*/React.createElement(CheckCircleFilled, null),
  process: /*#__PURE__*/React.createElement("span", {
    className: stepClassPrefix + "-item-icon-process"
  }),
  wait: /*#__PURE__*/React.createElement("span", {
    className: stepClassPrefix + "-item-icon-wait"
  })
};
var defaultProps = {
  current: 0,
  direction: 'horizontal'
};
var Steps = withDefaultProps(defaultProps)(function (props) {
  var direction = props.direction,
      current = props.current;
  var classString = classNames(classPrefix + "-" + direction);
  return /*#__PURE__*/React.createElement("div", {
    className: classString
  }, React.Children.map(props.children, function (child, index) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return child;
    }

    var props = child.props;
    var status = props.status || 'wait';
    var icon = props.icon; // 小于当前步骤的默认状态是进行中，大于当前步骤的是表示未完成。

    if (index < current) {
      status = props.status || 'finish';
    } else if (index === current) {
      status = props.status || 'process';
    }

    if (direction === 'vertical') {
      icon = icon || defaultIconMap[status];
    }

    return /*#__PURE__*/React.cloneElement(child, {
      status: status,
      icon: icon
    });
  }));
});
export default attachPropertiesToComponent(Steps, {
  Step: Step
});