"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

var react_1 = require("react");

var classnames_1 = __importDefault(require("classnames"));

var ahooks_1 = require("ahooks");

var icons_1 = require("@ant-design/icons");

var group_1 = require("./group");

var group_context_1 = require("./group-context");

var attach_properties_to_component_1 = require("../../utils/attach-properties-to-component");

var classPrefix = "am-checkbox";

var Checkbox = function Checkbox(props) {
  var _classnames_1$default;

  var groupContext = react_1.useContext(group_context_1.CheckboxGroupContext);

  var _ahooks_1$useControll = ahooks_1.useControllableValue(props, {
    valuePropName: 'checked',
    defaultValuePropName: 'defaultChecked',
    defaultValue: false
  }),
      checked = _ahooks_1$useControll[0],
      setChecked = _ahooks_1$useControll[1];

  var disabled = props.disabled;
  var value = props.value;

  if (groupContext && value) {
    checked = groupContext.value.includes(value);

    setChecked = function setChecked(checked) {
      if (checked) {
        groupContext.check(value);
      } else {
        groupContext.uncheck(value);
      }

      props.onChange == null ? void 0 : props.onChange(checked);
    };

    disabled = disabled || groupContext.disabled;
  }

  return /*#__PURE__*/React.createElement("label", {
    className: classnames_1["default"](classPrefix, props.className, (_classnames_1$default = {}, _classnames_1$default[classPrefix + "-checked"] = checked, _classnames_1$default[classPrefix + "-indeterminate"] = props.indeterminate, _classnames_1$default[classPrefix + "-disabled"] = disabled, _classnames_1$default)),
    style: props.style
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    checked: checked,
    onChange: function onChange(e) {
      setChecked(e.target.checked);
    },
    onClick: function onClick(e) {
      e.stopPropagation();
      e.nativeEvent.stopImmediatePropagation();
    },
    disabled: disabled
  }), /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-icon"
  }, /*#__PURE__*/React.createElement(icons_1.CheckOutlined, {
    className: classPrefix + "-icon-checked"
  }), /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-indeterminate-checked"
  })), props.children && /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-content"
  }, props.children));
};

exports["default"] = attach_properties_to_component_1.attachPropertiesToComponent(Checkbox, {
  Group: group_1.Group
});