"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

var react_1 = require("react");

var picker_1 = __importDefault(require("../picker"));

var ahooks_1 = require("ahooks");

var dayjs_1 = __importDefault(require("dayjs"));

var generate_int_array_1 = require("../../utils/generate-int-array");

var with_default_props_1 = require("../../utils/with-default-props");

var thisYear = new Date().getFullYear();
var defaultProps = {
  min: new Date(new Date().setFullYear(thisYear - 10)),
  max: new Date(new Date().setFullYear(thisYear + 10))
};
var DatePicker = with_default_props_1.withDefaultProps(defaultProps)(function (props) {
  var _ahooks_1$useControll = ahooks_1.useControllableValue(props, {
    trigger: 'onConfirm'
  }),
      value = _ahooks_1$useControll[0],
      setValue = _ahooks_1$useControll[1];

  function columns(selected) {
    var years = [];
    var minYear = props.min.getFullYear();
    var minMonth = props.min.getMonth() + 1;
    var minDate = props.min.getDate();
    var maxYear = props.max.getFullYear();
    var maxMonth = props.max.getMonth() + 1;
    var maxDate = props.max.getDate();
    var firstDayInSelectedMonth = dayjs_1["default"](convertStringArrayToDate([selected[0], selected[1], '1']));
    var selectedYear = firstDayInSelectedMonth.year();
    var selectedMonth = firstDayInSelectedMonth.month() + 1;

    for (var i = minYear; i <= maxYear; i++) {
      years.push(i.toString());
    }

    var months = generate_int_array_1.generateIntArray(1, 12).filter(function (v) {
      if (selectedYear === minYear && v < minMonth) {
        return false;
      }

      if (selectedYear === maxYear && v > maxMonth) {
        return false;
      }

      return true;
    }).map(function (v) {
      return v.toString();
    });
    var days = [];
    days = generate_int_array_1.generateIntArray(1, firstDayInSelectedMonth.daysInMonth()).filter(function (v) {
      if (selectedYear === minYear && selectedMonth === minMonth && v < minDate) {
        return false;
      }

      if (selectedYear === maxYear && selectedMonth === maxMonth && v > maxDate) {
        return false;
      }

      return true;
    }).map(function (v) {
      return v.toString();
    });
    return [years, months, days];
  }

  var pickerValue = react_1.useMemo(function () {
    return convertDateToStringArray(value);
  }, [value]);
  var onConfirm = react_1.useCallback(function (val) {
    setValue(convertStringArrayToDate(val));
  }, [setValue]);
  var onSelect = react_1.useCallback(function (val) {
    props.onSelect == null ? void 0 : props.onSelect(convertStringArrayToDate(val));
  }, [props.onSelect]);
  return /*#__PURE__*/React.createElement(picker_1["default"], {
    columns: columns,
    value: pickerValue,
    onCancel: props.onCancel,
    onClose: props.onClose,
    visible: props.visible,
    confirmText: props.confirmText,
    cancelText: props.cancelText,
    onConfirm: onConfirm,
    onSelect: onSelect,
    getContainer: props.getContainer
  });
});

function convertDateToStringArray(date) {
  if (!date) return [];
  return [date.getFullYear().toString(), (date.getMonth() + 1).toString(), date.getDate().toString()];
}

function convertStringArrayToDate(value) {
  var _value$ = value[0],
      yearString = _value$ === void 0 ? '1900' : _value$,
      _value$2 = value[1],
      monthString = _value$2 === void 0 ? '1' : _value$2,
      _value$3 = value[2],
      dateString = _value$3 === void 0 ? '1' : _value$3;
  return new Date(parseInt(yearString), parseInt(monthString) - 1, parseInt(dateString));
}

exports["default"] = DatePicker;