"use strict";

function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }

  if (!value || !value.then) {
    value = Promise.resolve(value);
  }

  return then ? value.then(then) : value;
}

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

function _empty() {}

function _awaitIgnored(value, direct) {
  if (!direct) {
    return value && value.then ? value.then(_empty) : Promise.resolve();
  }
}

function _invoke(body, then) {
  var result = body();

  if (result && result.then) {
    return result.then(then);
  }

  return then(result);
}

function _continue(value, then) {
  return value && value.then ? value.then(then) : then(value);
}

function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }

    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultProps = void 0;

var with_default_props_1 = require("../../utils/with-default-props");

var web_1 = require("@react-spring/web");

var react_use_gesture_1 = require("react-use-gesture");

var get_scroll_parent_1 = require("../../utils/get-scroll-parent");

var react_1 = require("react");

var supports_passive_1 = require("../../utils/supports-passive");

var convert_px_1 = require("../../utils/convert-px");

var rubberband_1 = require("../../utils/rubberband");

var sleep_1 = require("../../utils/sleep");

var classPrefix = "am-pull-to-refresh";
var PullStatus;

(function (PullStatus) {
  PullStatus[PullStatus["idle"] = 0] = "idle";
  PullStatus[PullStatus["thresholdMet"] = 1] = "thresholdMet";
  PullStatus[PullStatus["refreshing"] = 2] = "refreshing";
  PullStatus[PullStatus["complete"] = 3] = "complete";
})(PullStatus || (PullStatus = {}));

exports.defaultProps = {
  pullingText: '下拉刷新',
  releaseText: '释放立即刷新',
  refreshingText: '加载中……',
  completeText: '刷新成功',
  completeDelay: 500,
  headHeight: convert_px_1.convertPx(40),
  threshold: convert_px_1.convertPx(60),
  onRefresh: function onRefresh() {}
};
var PullToRefresh = with_default_props_1.withDefaultProps(exports.defaultProps)(function (props) {
  var doRefresh = _async(function () {
    var _exit = false;
    api.start({
      height: props.headHeight
    });
    setStatus(PullStatus.refreshing);
    setStatus(PullStatus.refreshing);
    return _continue(_catch(function () {
      return _await(props.onRefresh(), function () {
        setStatus(PullStatus.complete);
      });
    }, function (e) {
      setStatus(PullStatus.idle);
      throw e;
    }), function (_result) {
      return _exit ? _result : _invoke(function () {
        if (props.completeDelay > 0) {
          return _awaitIgnored(sleep_1.sleep(props.completeDelay));
        }
      }, function () {
        api.start({
          to: _async(function (next) {
            return _await(next({
              height: 0
            }), function () {
              return _await(next({
                height: 0
              }), function () {
                setStatus(PullStatus.idle);
              });
            });
          })
        });
      });
    });
  });

  var _react_1$useState = react_1.useState(PullStatus.idle),
      status = _react_1$useState[0],
      setStatus = _react_1$useState[1];

  var _web_1$useSpring = web_1.useSpring(function () {
    return {
      from: {
        height: 0
      },
      config: {
        tension: 300,
        friction: 30,
        clamp: true
      }
    };
  }),
      springStyles = _web_1$useSpring[0],
      api = _web_1$useSpring[1];

  var elementRef = react_1.useRef(null);
  var pullingRef = react_1.useRef(false);
  react_use_gesture_1.useDrag(function (state) {
    if (status === PullStatus.refreshing || status === PullStatus.complete) return;
    var event = state.event;

    if (state.last) {
      pullingRef.current = false;

      if (status === PullStatus.thresholdMet) {
        doRefresh();
      } else {
        api.start({
          height: 0
        });
      }

      return;
    }

    var _state$movement = state.movement,
        x = _state$movement[0],
        y = _state$movement[1];

    if (state.first) {
      var element = elementRef.current;
      if (!element) return;
      var scrollParent = get_scroll_parent_1.getScrollParent(element);
      if (!scrollParent) return;
      var top = 'scrollTop' in scrollParent ? scrollParent.scrollTop : scrollParent.pageYOffset;

      if (top <= 0 && y > 0) {
        pullingRef.current = true;
      }
    }

    if (!pullingRef.current) return;

    if (typeof event.cancelable !== 'boolean' || event.cancelable) {
      event.preventDefault();
    }

    event.stopPropagation();
    var height = Math.max(rubberband_1.rubberbandIfOutOfBounds(y, 0, 0, props.headHeight * 5, 0.5), 0);
    api.start({
      height: height
    });
    setStatus(height > props.threshold ? PullStatus.thresholdMet : PullStatus.idle);
  }, {
    useTouch: true,
    axis: 'y',
    domTarget: elementRef,
    eventOptions: supports_passive_1.supportsPassive ? {
      passive: false
    } : false
  });
  return /*#__PURE__*/React.createElement(web_1.animated.div, {
    ref: elementRef,
    className: classPrefix
  }, /*#__PURE__*/React.createElement(web_1.animated.div, {
    style: springStyles,
    className: classPrefix + "-head"
  }, /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-head-content",
    style: {
      height: props.headHeight
    }
  }, status === PullStatus.idle && props.pullingText, status === PullStatus.thresholdMet && props.releaseText, status === PullStatus.refreshing && props.refreshingText, status === PullStatus.complete && props.completeText)), /*#__PURE__*/React.createElement("div", null, props.children));
});
exports["default"] = PullToRefresh;